@@ -75,6 +75,7 @@ static CfgLexerKeyword main_keywords[] =
   { "scope",              KW_SCOPE },
   { "rekey",              KW_REKEY },
   { "shift",              KW_SHIFT },
+  { "shift_levels",       KW_SHIFT_LEVELS },
   { "add_prefix",         KW_ADD_PREFIX },
   { "replace",            KW_REPLACE_PREFIX, KWS_OBSOLETE, "replace_prefix" },
   { "replace_prefix",     KW_REPLACE_PREFIX },
@@ -82,6 +83,7 @@ static CfgLexerKeyword main_keywords[] =
   /* option items */
   { "flags",              KW_FLAGS },
   { "pad_size",           KW_PAD_SIZE },
+  { "truncate_size",      KW_TRUNCATE_SIZE },
   { "mark_freq",          KW_MARK_FREQ },
   { "mark",               KW_MARK_FREQ, KWS_OBSOLETE, "mark_freq" },
   { "mark_mode",          KW_MARK_MODE },
@@ -98,7 +100,7 @@ static CfgLexerKeyword main_keywords[] =
   { "sync",               KW_FLUSH_LINES, KWS_OBSOLETE, "flush_lines" },
   { "long_hostnames",     KW_CHAIN_HOSTNAMES, KWS_OBSOLETE, "chain_hostnames" },
   { "chain_hostnames",    KW_CHAIN_HOSTNAMES },
-  { "normalize_hostnames",KW_NORMALIZE_HOSTNAMES },
+  { "normalize_hostnames", KW_NORMALIZE_HOSTNAMES },
   { "keep_hostname",      KW_KEEP_HOSTNAME },
   { "check_hostname",     KW_CHECK_HOSTNAME },
   { "bad_hostname",       KW_BAD_HOSTNAME },
@@ -120,8 +122,9 @@ static CfgLexerKeyword main_keywords[] =
   { "time_sleep",         KW_TIME_SLEEP, KWS_OBSOLETE, "time_sleep() has been deprecated" },
   { "file_template",      KW_FILE_TEMPLATE },
   { "proto_template",     KW_PROTO_TEMPLATE },
-  { "default_level",      KW_DEFAULT_LEVEL },
-  { "default_priority",   KW_DEFAULT_LEVEL },
+  { "default_level",      KW_DEFAULT_SEVERITY },
+  { "default_priority",   KW_DEFAULT_SEVERITY },
+  { "default_severity",   KW_DEFAULT_SEVERITY },
   { "default_facility",   KW_DEFAULT_FACILITY },
   { "threaded",           KW_THREADED },
   { "use_rcptid",         KW_USE_RCPTID, KWS_OBSOLETE, "This has been deprecated, try use_uniqid() instead" },
@@ -160,10 +163,12 @@ static CfgLexerKeyword main_keywords[] =
   { "persist_name",            KW_PERSIST_NAME, VERSION_VALUE_3_8 },
 
   { "retries",            KW_RETRIES },
+  { "workers",            KW_WORKERS },
   { "batch_lines",        KW_BATCH_LINES },
   { "batch_timeout",      KW_BATCH_TIMEOUT },
 
   { "read_old_records",   KW_READ_OLD_RECORDS},
+  { "use_syslogng_pid",   KW_USE_SYSLOGNG_PID },
   { "fetch_no_data_delay", KW_FETCH_NO_DATA_DELAY},
   /* filter items */
   { "type",               KW_TYPE },
@@ -174,6 +179,10 @@ static CfgLexerKeyword main_keywords[] =
   { "on",                 KW_YES },
   { "no",                 KW_NO },
   { "off",                KW_NO },
+  /* rewrite rules */
+  { "condition",          KW_CONDITION },
+  { "value",              KW_VALUE },
+
   { NULL, 0 }
 };
 
@@ -189,7 +198,7 @@ CfgParser main_parser =
   .parse = main_parse,
 };
 
-CFG_PARSER_IMPLEMENT_LEXER_BINDING(main_, gpointer *)
+CFG_PARSER_IMPLEMENT_LEXER_BINDING(main_, MAIN_, gpointer *)
 
 /* display CONTEXT lines before and after the offending line */
 #define CONTEXT 5
@@ -224,7 +233,7 @@ _print_underline(const gchar *line, gint whitespace_before, gint number_of_caret
 }
 
 static void
-_print_underlined_source_block(YYLTYPE *yylloc, gchar **lines, gint error_index)
+_print_underlined_source_block(CFG_LTYPE *yylloc, gchar **lines, gint error_index)
 {
   gint line_ndx;
   gchar line_prefix[12];
@@ -259,18 +268,19 @@ _print_underlined_source_block(YYLTYPE *yylloc, gchar **lines, gint error_index)
 }
 
 static void
-_report_file_location(const gchar *filename, YYLTYPE *yylloc)
+_report_file_location(const gchar *filename, CFG_LTYPE *yylloc)
 {
   FILE *f;
   gint lineno = 0;
-  gchar buf[1024];
+  gsize buflen = 65520;
+  gchar *buf = g_malloc(buflen);
   GPtrArray *context = g_ptr_array_new();
   gint error_index = 0;
 
   f = fopen(filename, "r");
   if (f)
     {
-      while (fgets(buf, sizeof(buf), f))
+      while (fgets(buf, buflen, f))
         {
           lineno++;
           if (lineno > (gint) yylloc->first_line + CONTEXT)
@@ -290,12 +300,13 @@ _report_file_location(const gchar *filename, YYLTYPE *yylloc)
   _print_underlined_source_block(yylloc, (gchar **) context->pdata, error_index);
 
 exit:
+  g_free(buf);
   g_ptr_array_foreach(context, (GFunc) g_free, NULL);
   g_ptr_array_free(context, TRUE);
 }
 
 static void
-_report_buffer_location(const gchar *buffer_content, YYLTYPE *yylloc)
+_report_buffer_location(const gchar *buffer_content, CFG_LTYPE *yylloc)
 {
   gchar **lines = g_strsplit(buffer_content, "\n", yylloc->first_line + CONTEXT + 1);
   gint num_lines = g_strv_length(lines);
@@ -317,45 +328,55 @@ exit:
 }
 
 void
-report_syntax_error(CfgLexer *lexer, YYLTYPE *yylloc, const char *what, const char *msg, gboolean in_main_grammar)
+report_syntax_error(CfgLexer *lexer, CFG_LTYPE *yylloc, const char *what, const char *msg, gboolean in_main_grammar)
 {
   CfgIncludeLevel *level = yylloc->level, *from;
 
   for (from = level; from >= lexer->include_stack; from--)
     {
+      CFG_LTYPE *from_lloc;
+
       if (from == level)
         {
+          /* the location on the initial level is the one we get as
+           * argument, instead of what we have in the lexer's state.  This
+           * is because the lexer might be one token in advance (because of
+           * LALR) and the grammar is kind enough to pass us the original
+           * location.  */
+
+          from_lloc = yylloc;
           fprintf(stderr, "Error parsing %s, %s in %s:%d:%d-%d:%d:\n",
                   what,
                   msg,
-                  from->lloc.level->name,
-                  from->lloc.first_line,
-                  from->lloc.first_column,
-                  from->lloc.last_line,
-                  from->lloc.last_column);
+                  from_lloc->level->name,
+                  from_lloc->first_line,
+                  from_lloc->first_column,
+                  from_lloc->last_line,
+                  from_lloc->last_column);
         }
       else
         {
+          from_lloc = &from->lloc;
           fprintf(stderr, "Included from %s:%d:%d-%d:%d:\n", from->name,
-                  from->lloc.first_line,
-                  from->lloc.first_column,
-                  from->lloc.last_line,
-                  from->lloc.last_column);
+                  from_lloc->first_line,
+                  from_lloc->first_column,
+                  from_lloc->last_line,
+                  from_lloc->last_column);
         }
       if (from->include_type == CFGI_FILE)
         {
-          _report_file_location(from->name, &from->lloc);
+          _report_file_location(from->name, from_lloc);
         }
       else if (from->include_type == CFGI_BUFFER)
         {
-          _report_buffer_location(from->buffer.original_content, &from->lloc);
+          _report_buffer_location(from->buffer.original_content, from_lloc);
         }
       fprintf(stderr, "\n");
     }
 
   if (in_main_grammar)
-    fprintf(stderr, "\nsyslog-ng documentation: https://www.balabit.com/support/documentation?product=%s\n"
-            "contact: %s\n", PRODUCT_NAME, PRODUCT_CONTACT);
+    fprintf(stderr, "\nsyslog-ng documentation: %s\n"
+            "contact: %s\n", PRODUCT_DOCUMENTATION, PRODUCT_CONTACT);
 
 }
 
