@@ -29,16 +29,23 @@ typedef struct _FilterOp
   FilterExprNode *left, *right;
 } FilterOp;
 
-static void
+static gboolean
 fop_init(FilterExprNode *s, GlobalConfig *cfg)
 {
   FilterOp *self = (FilterOp *) s;
 
-  if (self->left && self->left->init)
-    self->left->init(self->left, cfg);
-  if (self->right && self->right->init)
-    self->right->init(self->right, cfg);
+  g_assert(self->left);
+  g_assert(self->right);
+
+  if (!filter_expr_init(self->left, cfg))
+    return FALSE;
+
+  if (!filter_expr_init(self->right, cfg))
+    return FALSE;
+
   self->super.modify = self->left->modify || self->right->modify;
+
+  return TRUE;
 }
 
 static void
@@ -59,11 +66,12 @@ fop_init_instance(FilterOp *self)
 }
 
 static gboolean
-fop_or_eval(FilterExprNode *s, LogMessage **msgs, gint num_msg)
+fop_or_eval(FilterExprNode *s, LogMessage **msgs, gint num_msg, LogTemplateEvalOptions *options)
 {
   FilterOp *self = (FilterOp *) s;
 
-  return (filter_expr_eval_with_context(self->left, msgs, num_msg) || filter_expr_eval_with_context(self->right, msgs, num_msg)) ^ s->comp;
+  return (filter_expr_eval_with_context(self->left, msgs, num_msg, options)
+          || filter_expr_eval_with_context(self->right, msgs, num_msg, options)) ^ s->comp;
 }
 
 FilterExprNode *
@@ -80,11 +88,12 @@ fop_or_new(FilterExprNode *e1, FilterExprNode *e2)
 }
 
 static gboolean
-fop_and_eval(FilterExprNode *s, LogMessage **msgs, gint num_msg)
+fop_and_eval(FilterExprNode *s, LogMessage **msgs, gint num_msg, LogTemplateEvalOptions *options)
 {
   FilterOp *self = (FilterOp *) s;
 
-  return (filter_expr_eval_with_context(self->left, msgs, num_msg) && filter_expr_eval_with_context(self->right, msgs, num_msg)) ^ s->comp;
+  return (filter_expr_eval_with_context(self->left, msgs, num_msg, options)
+          && filter_expr_eval_with_context(self->right, msgs, num_msg, options)) ^ s->comp;
 }
 
 FilterExprNode *
