@@ -80,6 +80,7 @@ static void
 assert_log_msg_clear_clears_all_properties(LogMessage *message, NVHandle nv_handle,
                                            NVHandle sd_handle, const gchar *tag_name)
 {
+  message->flags |= LF_LOCAL + LF_UTF8 + LF_INTERNAL + LF_MARK;
   log_msg_clear(message);
 
   cr_assert_str_empty(log_msg_get_value(message, nv_handle, NULL),
@@ -91,6 +92,10 @@ assert_log_msg_clear_clears_all_properties(LogMessage *message, NVHandle nv_hand
   cr_assert_null(message->saddr, "Message still contains an saddr after log_msg_clear");
   cr_assert_not(log_msg_is_tag_by_name(message, tag_name),
                 "Message still contains a valid tag after log_msg_clear");
+  cr_assert((message->flags & LF_LOCAL) == 0, "Message still contains the 'local' flag after log_msg_clear");
+  cr_assert((message->flags & LF_UTF8) == 0, "Message still contains the 'utf8' flag after log_msg_clear");
+  cr_assert((message->flags & LF_MARK) == 0, "Message still contains the 'mark' flag after log_msg_clear");
+  cr_assert((message->flags & LF_INTERNAL) == 0, "Message still contains the 'internal' flag after log_msg_clear");
 }
 
 static void
@@ -185,6 +190,35 @@ Test(log_message, test_log_message_can_be_cleared)
   log_message_test_params_free(params);
 }
 
+Test(log_message, test_log_msg_clear_handles_cloned_noninline_tags_properly)
+{
+  LogMessage *msg = _construct_log_message();
+
+  for (gint i = 0; i < 100; i++)
+    {
+      gchar tag_name[32];
+
+      g_snprintf(tag_name, sizeof(tag_name), "tag%d", i);
+      log_msg_set_tag_by_name(msg, tag_name);
+    }
+
+  LogPathOptions path_options = LOG_PATH_OPTIONS_INIT;
+  LogMessage *cloned = log_msg_clone_cow(msg, &path_options);
+
+  log_msg_clear(cloned);
+
+  for (gint i = 0; i < 100; i++)
+    {
+      gchar tag_name[32];
+
+      g_snprintf(tag_name, sizeof(tag_name), "tag%d", i);
+      cr_assert(log_msg_is_tag_by_name(cloned, tag_name) == FALSE);
+    }
+  log_msg_unref(cloned);
+  log_msg_unref(msg);
+
+}
+
 Test(log_message, test_rcptid_is_automatically_assigned_to_a_newly_created_log_message)
 {
   LogMessage *msg;
