@@ -25,7 +25,9 @@
 #include "logwriter.h"
 #include "messages.h"
 #include "stats/stats-registry.h"
+#include "stats/aggregator/stats-aggregator-registry.h"
 #include "stats/stats-cluster-single.h"
+#include "stats/aggregator/stats-aggregator.h"
 #include "hostname.h"
 #include "host-resolve.h"
 #include "seqnum.h"
@@ -70,6 +72,9 @@ struct _LogWriter
   StatsCounterItem *suppressed_messages;
   StatsCounterItem *processed_messages;
   StatsCounterItem *written_messages;
+  StatsAggregator *max_message_size;
+  StatsAggregator *average_messages_size;
+  StatsAggregator *CPS;
   struct
   {
     StatsCounterItem *count;
@@ -1150,6 +1155,13 @@ log_writer_flush_finalize(LogWriter *self)
   return FALSE;
 }
 
+static void
+_log_writer_insert_msg_length_stats(LogWriter *self, gsize msg_len)
+{
+  stats_aggregator_insert_data(self->max_message_size, msg_len);
+  stats_aggregator_insert_data(self->average_messages_size, msg_len);
+}
+
 static gboolean
 log_writer_write_message(LogWriter *self, LogMessage *msg, LogPathOptions *path_options, gboolean *write_error)
 {
@@ -1168,8 +1180,10 @@ log_writer_write_message(LogWriter *self, LogMessage *msg, LogPathOptions *path_
                 evt_tag_printf("message", "%s", self->line_buffer->str));
     }
 
+  gsize msg_len = 0;
   if (self->line_buffer->len)
     {
+      msg_len = self->line_buffer->len;
       LogProtoStatus status = log_proto_client_post(self->proto, msg, (guchar *)self->line_buffer->str,
                                                     self->line_buffer->len,
                                                     &consumed);
@@ -1211,6 +1225,7 @@ log_writer_write_message(LogWriter *self, LogMessage *msg, LogPathOptions *path_
       log_msg_unref(msg);
       msg_set_context(NULL);
       log_msg_refcache_stop();
+      _log_writer_insert_msg_length_stats(self, msg_len);
 
       return TRUE;
     }
@@ -1389,36 +1404,68 @@ log_writer_init_watches(LogWriter *self)
   self->io_job.release = (void (*)(void *)) log_pipe_unref;
 }
 
+static void
+_register_aggregated_stats(LogWriter *self, StatsClusterKey *sc_key_input, gint stats_type)
+{
+  stats_aggregator_lock();
+  StatsClusterKey sc_key;
+
+  stats_cluster_single_key_set_with_name(&sc_key, self->options->stats_source | SCS_DESTINATION, self->stats_id,
+                                         self->stats_instance, "msg_size_max");
+  stats_register_aggregator_maximum(self->options->stats_level, &sc_key, &self->max_message_size);
+
+  stats_cluster_single_key_set_with_name(&sc_key, self->options->stats_source | SCS_DESTINATION, self->stats_id,
+                                         self->stats_instance, "msg_size_avg");
+  stats_register_aggregator_average(self->options->stats_level, &sc_key, &self->average_messages_size);
+
+  stats_cluster_single_key_set_with_name(&sc_key, self->options->stats_source | SCS_DESTINATION, self->stats_id,
+                                         self->stats_instance, "eps");
+  stats_register_aggregator_cps(self->options->stats_level, &sc_key, sc_key_input, stats_type, &self->CPS);
+
+  stats_aggregator_unlock();
+}
+
+static void
+_unregister_aggregated_stats(LogWriter *self)
+{
+  stats_aggregator_lock();
+
+  stats_unregister_aggregator_maximum(&self->max_message_size);
+  stats_unregister_aggregator_average(&self->average_messages_size);
+  stats_unregister_aggregator_cps(&self->CPS);
+
+  stats_aggregator_unlock();
+}
+
 static void
 _register_counters(LogWriter *self)
 {
   stats_lock();
-  {
-    StatsClusterKey sc_key;
-    stats_cluster_logpipe_key_set(&sc_key, self->options->stats_source | SCS_DESTINATION, self->stats_id,
-                                  self->stats_instance);
+  StatsClusterKey sc_key;
+  stats_cluster_logpipe_key_set(&sc_key, self->options->stats_source | SCS_DESTINATION, self->stats_id,
+                                self->stats_instance);
 
-    if (self->options->suppress > 0)
-      stats_register_counter(self->options->stats_level, &sc_key, SC_TYPE_SUPPRESSED, &self->suppressed_messages);
-    stats_register_counter(self->options->stats_level, &sc_key, SC_TYPE_DROPPED, &self->dropped_messages);
-    stats_register_counter(self->options->stats_level, &sc_key, SC_TYPE_PROCESSED, &self->processed_messages);
-    stats_register_counter(self->options->stats_level, &sc_key, SC_TYPE_WRITTEN, &self->written_messages);
-    log_queue_register_stats_counters(self->queue, self->options->stats_level, &sc_key);
+  if (self->options->suppress > 0)
+    stats_register_counter(self->options->stats_level, &sc_key, SC_TYPE_SUPPRESSED, &self->suppressed_messages);
+  stats_register_counter(self->options->stats_level, &sc_key, SC_TYPE_DROPPED, &self->dropped_messages);
+  stats_register_counter(self->options->stats_level, &sc_key, SC_TYPE_PROCESSED, &self->processed_messages);
+  stats_register_counter(self->options->stats_level, &sc_key, SC_TYPE_WRITTEN, &self->written_messages);
+  log_queue_register_stats_counters(self->queue, self->options->stats_level, &sc_key);
 
-    StatsClusterKey sc_key_truncated_count;
-    stats_cluster_single_key_set_with_name(&sc_key_truncated_count, self->options->stats_source | SCS_DESTINATION,
-                                           self->stats_id, self->stats_instance, "truncated_count");
-    stats_register_counter(self->options->stats_level, &sc_key_truncated_count, SC_TYPE_SINGLE_VALUE,
-                           &self->truncated.count);
+  StatsClusterKey sc_key_truncated_count;
+  stats_cluster_single_key_set_with_name(&sc_key_truncated_count, self->options->stats_source | SCS_DESTINATION,
+                                         self->stats_id, self->stats_instance, "truncated_count");
+  stats_register_counter(self->options->stats_level, &sc_key_truncated_count, SC_TYPE_SINGLE_VALUE,
+                         &self->truncated.count);
 
-    StatsClusterKey sc_key_truncated_bytes;
-    stats_cluster_single_key_set_with_name(&sc_key_truncated_bytes, self->options->stats_source | SCS_DESTINATION,
-                                           self->stats_id, self->stats_instance, "truncated_bytes");
-    stats_register_counter(self->options->stats_level, &sc_key_truncated_bytes, SC_TYPE_SINGLE_VALUE,
-                           &self->truncated.bytes);
+  StatsClusterKey sc_key_truncated_bytes;
+  stats_cluster_single_key_set_with_name(&sc_key_truncated_bytes, self->options->stats_source | SCS_DESTINATION,
+                                         self->stats_id, self->stats_instance, "truncated_bytes");
+  stats_register_counter(self->options->stats_level, &sc_key_truncated_bytes, SC_TYPE_SINGLE_VALUE,
+                         &self->truncated.bytes);
 
-  }
   stats_unlock();
+  _register_aggregated_stats(self, &sc_key, SC_TYPE_WRITTEN);
 }
 
 static gboolean
@@ -1480,8 +1527,10 @@ _unregister_counters(LogWriter *self)
     stats_unregister_counter(&sc_key_truncated_bytes, SC_TYPE_SINGLE_VALUE, &self->truncated.bytes);
 
     log_queue_unregister_stats_counters(self->queue, &sc_key);
+
   }
   stats_unlock();
+  _unregister_aggregated_stats(self);
 
 }
 
