@@ -23,6 +23,7 @@
  */
 
 #include "rewrite-set.h"
+#include "scratch-buffers.h"
 
 /* LogRewriteSet
  *
@@ -37,10 +38,10 @@ struct _LogRewriteSet
   LogTemplateOptions template_options;
 };
 
-LogTemplateOptions*
+LogTemplateOptions *
 log_rewrite_set_get_template_options(LogRewrite *s)
 {
-  LogRewriteSet *self = (LogRewriteSet*) s;
+  LogRewriteSet *self = (LogRewriteSet *) s;
   return &self->template_options;
 }
 
@@ -50,12 +51,13 @@ log_rewrite_set_process(LogRewrite *s, LogMessage **pmsg, const LogPathOptions *
   LogRewriteSet *self = (LogRewriteSet *) s;
   GString *result;
 
-  result = g_string_sized_new(64);
-  log_template_format(self->value_template, *pmsg, &self->template_options, LTZ_SEND, 0, NULL, result);
+  result = scratch_buffers_alloc();
+
+  LogTemplateEvalOptions options = {&self->template_options, LTZ_SEND, 0, NULL};
+  log_template_format(self->value_template, *pmsg, &options, result);
 
   log_msg_make_writable(pmsg, path_options);
   log_msg_set_value(*pmsg, self->super.value_handle, result->str, result->len);
-  g_string_free(result, TRUE);
 }
 
 static LogPipe *
