@@ -121,6 +121,7 @@ extern int afmongodb_debug;
     KW_TYPE = 10083,               /* KW_TYPE  */
     KW_STATS_MAX_DYNAMIC = 10084,  /* KW_STATS_MAX_DYNAMIC  */
     KW_MIN_IW_SIZE_PER_READER = 10085, /* KW_MIN_IW_SIZE_PER_READER  */
+    KW_WORKERS = 10086,            /* KW_WORKERS  */
     KW_BATCH_LINES = 10087,        /* KW_BATCH_LINES  */
     KW_BATCH_TIMEOUT = 10088,      /* KW_BATCH_TIMEOUT  */
     KW_TRIM_LARGE_MESSAGES = 10089, /* KW_TRIM_LARGE_MESSAGES  */
@@ -225,8 +226,7 @@ extern int afmongodb_debug;
     KW_FETCH_NO_DATA_DELAY = 10513, /* KW_FETCH_NO_DATA_DELAY  */
     KW_MONGODB = 10515,            /* KW_MONGODB  */
     KW_URI = 10516,                /* KW_URI  */
-    KW_COLLECTION = 10517,         /* KW_COLLECTION  */
-    KW_WORKERS = 10518             /* KW_WORKERS  */
+    KW_COLLECTION = 10517          /* KW_COLLECTION  */
   };
   typedef enum afmongodb_tokentype afmongodb_token_kind_t;
 #endif
@@ -286,6 +286,7 @@ extern int afmongodb_debug;
 #define KW_TYPE 10083
 #define KW_STATS_MAX_DYNAMIC 10084
 #define KW_MIN_IW_SIZE_PER_READER 10085
+#define KW_WORKERS 10086
 #define KW_BATCH_LINES 10087
 #define KW_BATCH_TIMEOUT 10088
 #define KW_TRIM_LARGE_MESSAGES 10089
@@ -391,7 +392,6 @@ extern int afmongodb_debug;
 #define KW_MONGODB 10515
 #define KW_URI 10516
 #define KW_COLLECTION 10517
-#define KW_WORKERS 10518
 
 /* Value type.  */
 #if ! defined AFMONGODB_STYPE && ! defined AFMONGODB_STYPE_IS_DECLARED
