@@ -113,6 +113,7 @@ extern int diskq_debug;
     KW_TYPE = 10083,               /* KW_TYPE  */
     KW_STATS_MAX_DYNAMIC = 10084,  /* KW_STATS_MAX_DYNAMIC  */
     KW_MIN_IW_SIZE_PER_READER = 10085, /* KW_MIN_IW_SIZE_PER_READER  */
+    KW_WORKERS = 10086,            /* KW_WORKERS  */
     KW_BATCH_LINES = 10087,        /* KW_BATCH_LINES  */
     KW_BATCH_TIMEOUT = 10088,      /* KW_BATCH_TIMEOUT  */
     KW_TRIM_LARGE_MESSAGES = 10089, /* KW_TRIM_LARGE_MESSAGES  */
@@ -222,7 +223,8 @@ extern int diskq_debug;
     KW_COMPACTION = 10519,         /* KW_COMPACTION  */
     KW_MEM_BUF_SIZE = 10520,       /* KW_MEM_BUF_SIZE  */
     KW_QOUT_SIZE = 10521,          /* KW_QOUT_SIZE  */
-    KW_DIR = 10522                 /* KW_DIR  */
+    KW_DIR = 10522,                /* KW_DIR  */
+    KW_TRUNCATE_SIZE_RATIO = 10523 /* KW_TRUNCATE_SIZE_RATIO  */
   };
   typedef enum diskq_tokentype diskq_token_kind_t;
 #endif
@@ -282,6 +284,7 @@ extern int diskq_debug;
 #define KW_TYPE 10083
 #define KW_STATS_MAX_DYNAMIC 10084
 #define KW_MIN_IW_SIZE_PER_READER 10085
+#define KW_WORKERS 10086
 #define KW_BATCH_LINES 10087
 #define KW_BATCH_TIMEOUT 10088
 #define KW_TRIM_LARGE_MESSAGES 10089
@@ -392,6 +395,7 @@ extern int diskq_debug;
 #define KW_MEM_BUF_SIZE 10520
 #define KW_QOUT_SIZE 10521
 #define KW_DIR 10522
+#define KW_TRUNCATE_SIZE_RATIO 10523
 
 /* Value type.  */
 #if ! defined DISKQ_STYPE && ! defined DISKQ_STYPE_IS_DECLARED
