@@ -64,9 +64,9 @@ Test(diskq, testcase_zero_diskbuf_and_normal_acks)
   log_queue_set_use_backlog(q, TRUE);
 
   filename = g_string_sized_new(32);
-  g_string_sprintf(filename,"test-normal_acks.qf");
+  g_string_sprintf(filename, "test-normal_acks.qf");
   unlink(filename->str);
-  log_queue_disk_load_queue(q,filename->str);
+  log_queue_disk_load_queue(q, filename->str);
   fed_messages = 0;
   acked_messages = 0;
   for (i = 0; i < 10; i++)
@@ -80,7 +80,7 @@ Test(diskq, testcase_zero_diskbuf_and_normal_acks)
 
   log_queue_unref(q);
   unlink(filename->str);
-  g_string_free(filename,TRUE);
+  g_string_free(filename, TRUE);
   disk_queue_options_destroy(&options);
 }
 
@@ -97,9 +97,9 @@ Test(diskq, testcase_zero_diskbuf_alternating_send_acks)
   log_queue_set_use_backlog(q, TRUE);
 
   filename = g_string_sized_new(32);
-  g_string_sprintf(filename,"test-send_acks.qf");
+  g_string_sprintf(filename, "test-send_acks.qf");
   unlink(filename->str);
-  log_queue_disk_load_queue(q,filename->str);
+  log_queue_disk_load_queue(q, filename->str);
   fed_messages = 0;
   acked_messages = 0;
   for (i = 0; i < 10; i++)
@@ -114,7 +114,7 @@ Test(diskq, testcase_zero_diskbuf_alternating_send_acks)
                acked_messages);
   log_queue_unref(q);
   unlink(filename->str);
-  g_string_free(filename,TRUE);
+  g_string_free(filename, TRUE);
   disk_queue_options_destroy(&options);
 }
 
@@ -131,7 +131,7 @@ Test(diskq, testcase_ack_and_rewind_messages)
   log_queue_set_use_backlog(q, TRUE);
 
   StatsClusterKey sc_key;
-  stats_cluster_logpipe_key_set(&sc_key, SCS_DESTINATION, "queued messages", NULL );
+  stats_cluster_logpipe_key_set(&sc_key, SCS_DESTINATION, "queued messages", NULL);
   stats_lock();
   stats_register_counter(0, &sc_key, SC_TYPE_QUEUED, &q->queued_messages);
   stats_unlock();
@@ -139,33 +139,33 @@ Test(diskq, testcase_ack_and_rewind_messages)
   cr_assert_eq(stats_counter_get(q->queued_messages), 0, "queued messages: %d", __LINE__);
 
   filename = g_string_sized_new(32);
-  g_string_sprintf(filename,"test-rewind_and_acks.qf");
+  g_string_sprintf(filename, "test-rewind_and_acks.qf");
   unlink(filename->str);
-  log_queue_disk_load_queue(q,filename->str);
+  log_queue_disk_load_queue(q, filename->str);
 
   fed_messages = 0;
   acked_messages = 0;
   feed_some_messages(q, 1000);
   cr_assert_eq(stats_counter_get(q->queued_messages), 1000, "queued messages: %d", __LINE__);
 
-  for(i = 0; i < 10; i++)
+  for (i = 0; i < 10; i++)
     {
-      send_some_messages(q,1);
+      send_some_messages(q, 1);
       cr_assert_eq(stats_counter_get(q->queued_messages), 999, "queued messages wrong number %d", __LINE__);
-      log_queue_rewind_backlog(q,1);
+      log_queue_rewind_backlog(q, 1);
       cr_assert_eq(stats_counter_get(q->queued_messages), 1000, "queued messages wrong number: %d", __LINE__);
     }
-  send_some_messages(q,1000);
+  send_some_messages(q, 1000);
   cr_assert_eq(stats_counter_get(q->queued_messages), 0, "queued messages: %d", __LINE__);
-  log_queue_ack_backlog(q,500);
-  log_queue_rewind_backlog(q,500);
+  log_queue_ack_backlog(q, 500);
+  log_queue_rewind_backlog(q, 500);
   cr_assert_eq(stats_counter_get(q->queued_messages), 500, "queued messages: %d", __LINE__);
-  send_some_messages(q,500);
+  send_some_messages(q, 500);
   cr_assert_eq(stats_counter_get(q->queued_messages), 0, "queued messages: %d", __LINE__);
-  log_queue_ack_backlog(q,500);
+  log_queue_ack_backlog(q, 500);
   log_queue_unref(q);
   unlink(filename->str);
-  g_string_free(filename,TRUE);
+  g_string_free(filename, TRUE);
   disk_queue_options_destroy(&options);
 }
 
@@ -233,7 +233,7 @@ threaded_consume(gpointer st)
       LogMessage *msg = NULL;
       gint slept = 0;
 
-      while(!msg)
+      while (!msg)
         {
           main_loop_worker_run_gc();
 
@@ -280,9 +280,9 @@ Test(diskq, testcase_with_threads)
 
       q = log_queue_disk_reliable_new(&options, NULL);
       filename = g_string_sized_new(32);
-      g_string_sprintf(filename,"test-%04d.qf",i);
+      g_string_sprintf(filename, "test-%04d.qf", i);
       unlink(filename->str);
-      log_queue_disk_load_queue(q,filename->str);
+      log_queue_disk_load_queue(q, filename->str);
 
       for (j = 0; j < FEEDERS; j++)
         {
@@ -299,7 +299,7 @@ Test(diskq, testcase_with_threads)
 
       log_queue_unref(q);
       unlink(filename->str);
-      g_string_free(filename,TRUE);
+      g_string_free(filename, TRUE);
       disk_queue_options_destroy(&options);
 
     }
@@ -365,7 +365,7 @@ ParameterizedTest(restart_test_parameters *test_case, diskq, testcase_diskbuffer
                "Corrupted disk-queue file does not exists!!");
   assert_string(qdisk_get_filename(disk_queue->qdisk), filename,
                 "New disk-queue file's name should be the same\n");
-  cr_assert_eq(qdisk_get_size(disk_queue->qdisk), original_disk_buf_size,
+  cr_assert_eq(qdisk_get_maximum_size(disk_queue->qdisk), original_disk_buf_size,
                "Disk-queue option does not match the original configured value!\n");
   cr_assert_eq(qdisk_get_length(disk_queue->qdisk), 0,
                "New disk-queue file should be empty!\n");
@@ -419,9 +419,9 @@ init_statistics(LogQueue *q)
 
   StatsClusterKey sc_key1, sc_key2;
   stats_lock();
-  stats_cluster_logpipe_key_set(&sc_key1, SCS_DESTINATION, "queued messages", NULL );
+  stats_cluster_logpipe_key_set(&sc_key1, SCS_DESTINATION, "queued messages", NULL);
   stats_register_counter(0, &sc_key1, SC_TYPE_QUEUED, &q->queued_messages);
-  stats_cluster_logpipe_key_set(&sc_key2, SCS_DESTINATION, "memory usage", NULL );
+  stats_cluster_logpipe_key_set(&sc_key2, SCS_DESTINATION, "memory usage", NULL);
   stats_register_counter(1, &sc_key2, SC_TYPE_MEMORY_USAGE, &q->memory_usage);
   stats_unlock();
   stats_counter_set(q->queued_messages, 0);
@@ -431,11 +431,11 @@ init_statistics(LogQueue *q)
 static void
 assert_general_message_flow(LogQueue *q, gssize one_msg_size)
 {
-  send_some_messages(q,1);
+  send_some_messages(q, 1);
   cr_assert_eq(stats_counter_get(q->queued_messages), 1, "queued messages: line: %d", __LINE__);
   cr_assert_eq(stats_counter_get(q->memory_usage), one_msg_size, "memory_usage: line: %d", __LINE__);
 
-  send_some_messages(q,1);
+  send_some_messages(q, 1);
   cr_assert_eq(stats_counter_get(q->queued_messages), 0, "queued messages: line: %d", __LINE__);
   cr_assert_eq(stats_counter_get(q->memory_usage), 0, "memory_usage: line: %d", __LINE__);
 
@@ -443,7 +443,7 @@ assert_general_message_flow(LogQueue *q, gssize one_msg_size)
   cr_assert_eq(stats_counter_get(q->queued_messages), 10, "queued messages: line: %d", __LINE__);
   cr_assert_eq(stats_counter_get(q->memory_usage), one_msg_size*10, "memory_usage: line: %d", __LINE__);
 
-  send_some_messages(q,5);
+  send_some_messages(q, 5);
   cr_assert_eq(stats_counter_get(q->queued_messages), 5, "queued messages: line: %d", __LINE__);
   cr_assert_eq(stats_counter_get(q->memory_usage), one_msg_size*5, "memory_usage: line: %d", __LINE__);
 }
@@ -463,7 +463,7 @@ testcase_diskq_prepare(DiskQueueOptions *options, diskq_tester_parameters_t *par
   cr_assert_eq(stats_counter_get(q->memory_usage), 0, "memory_usage: line: %d", __LINE__);
 
   unlink(parameters->filename);
-  log_queue_disk_load_queue(q,parameters->filename);
+  log_queue_disk_load_queue(q, parameters->filename);
 
   return q;
 }
@@ -575,7 +575,7 @@ ParameterizedTest(diskq_tester_parameters_t *test_cases, diskq, test_diskq_stati
 static void
 setup(void)
 {
-#if _AIX
+#if defined (_AIX)
   fprintf(stderr,
           "On AIX this testcase can't executed, because the overriding of main_loop_io_worker_register_finish_callback does not work\n");
   return 0;
