@@ -121,6 +121,7 @@ extern int kafka_debug;
     KW_TYPE = 10083,               /* KW_TYPE  */
     KW_STATS_MAX_DYNAMIC = 10084,  /* KW_STATS_MAX_DYNAMIC  */
     KW_MIN_IW_SIZE_PER_READER = 10085, /* KW_MIN_IW_SIZE_PER_READER  */
+    KW_WORKERS = 10086,            /* KW_WORKERS  */
     KW_BATCH_LINES = 10087,        /* KW_BATCH_LINES  */
     KW_BATCH_TIMEOUT = 10088,      /* KW_BATCH_TIMEOUT  */
     KW_TRIM_LARGE_MESSAGES = 10089, /* KW_TRIM_LARGE_MESSAGES  */
@@ -227,13 +228,11 @@ extern int kafka_debug;
     KW_TOPIC = 10516,              /* KW_TOPIC  */
     KW_FALLBACK_TOPIC = 10517,     /* KW_FALLBACK_TOPIC  */
     KW_CONFIG = 10518,             /* KW_CONFIG  */
-    KW_WORKERS = 10519,            /* KW_WORKERS  */
-    KW_FLUSH_TIMEOUT_ON_SHUTDOWN = 10520, /* KW_FLUSH_TIMEOUT_ON_SHUTDOWN  */
-    KW_FLUSH_TIMEOUT_ON_RELOAD = 10521, /* KW_FLUSH_TIMEOUT_ON_RELOAD  */
-    KW_POLL_TIMEOUT = 10522,       /* KW_POLL_TIMEOUT  */
-    KW_BOOTSTRAP_SERVERS = 10523,  /* KW_BOOTSTRAP_SERVERS  */
-    KW_SYNC_SEND = 10524,          /* KW_SYNC_SEND  */
-    KW_PROPERTIES_FILE = 10525     /* KW_PROPERTIES_FILE  */
+    KW_FLUSH_TIMEOUT_ON_SHUTDOWN = 10519, /* KW_FLUSH_TIMEOUT_ON_SHUTDOWN  */
+    KW_FLUSH_TIMEOUT_ON_RELOAD = 10520, /* KW_FLUSH_TIMEOUT_ON_RELOAD  */
+    KW_POLL_TIMEOUT = 10521,       /* KW_POLL_TIMEOUT  */
+    KW_BOOTSTRAP_SERVERS = 10522,  /* KW_BOOTSTRAP_SERVERS  */
+    KW_SYNC_SEND = 10523           /* KW_SYNC_SEND  */
   };
   typedef enum kafka_tokentype kafka_token_kind_t;
 #endif
@@ -293,6 +292,7 @@ extern int kafka_debug;
 #define KW_TYPE 10083
 #define KW_STATS_MAX_DYNAMIC 10084
 #define KW_MIN_IW_SIZE_PER_READER 10085
+#define KW_WORKERS 10086
 #define KW_BATCH_LINES 10087
 #define KW_BATCH_TIMEOUT 10088
 #define KW_TRIM_LARGE_MESSAGES 10089
@@ -399,13 +399,11 @@ extern int kafka_debug;
 #define KW_TOPIC 10516
 #define KW_FALLBACK_TOPIC 10517
 #define KW_CONFIG 10518
-#define KW_WORKERS 10519
-#define KW_FLUSH_TIMEOUT_ON_SHUTDOWN 10520
-#define KW_FLUSH_TIMEOUT_ON_RELOAD 10521
-#define KW_POLL_TIMEOUT 10522
-#define KW_BOOTSTRAP_SERVERS 10523
-#define KW_SYNC_SEND 10524
-#define KW_PROPERTIES_FILE 10525
+#define KW_FLUSH_TIMEOUT_ON_SHUTDOWN 10519
+#define KW_FLUSH_TIMEOUT_ON_RELOAD 10520
+#define KW_POLL_TIMEOUT 10521
+#define KW_BOOTSTRAP_SERVERS 10522
+#define KW_SYNC_SEND 10523
 
 /* Value type.  */
 #if ! defined KAFKA_STYPE && ! defined KAFKA_STYPE_IS_DECLARED
