@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015 Balabit
+ * Copyright (c) 2015-2019 Balabit
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -18,37 +18,15 @@
  * OpenSSL libraries as published by the OpenSSL project. See the file
  * COPYING for details.
  */
-#include "testutils.h"
+
 #include "kv-parser.h"
 #include "apphook.h"
 #include "msg_parse_lib.h"
+#include "scratch-buffers.h"
 
-#define kv_parser_testcase_begin(func, args)             \
-  do                                                            \
-    {                                                           \
-      testcase_begin("%s(%s)", func, args);                     \
-      kv_parser =                                               \
-        kv_parser_new(NULL);        \
-      log_pipe_init((LogPipe*)kv_parser);                 \
-    }                                                           \
-  while (0)
-
-#define kv_parser_testcase_end()                           \
-  do                                                            \
-    {                                                           \
-      log_pipe_deinit((LogPipe*)kv_parser);                     \
-      log_pipe_unref(&kv_parser->super);                  \
-      testcase_end();                                           \
-    }                                                           \
-  while (0)
-
-#define KV_PARSER_TESTCASE(x, ...) \
-  do {                                                          \
-      kv_parser_testcase_begin(#x, #__VA_ARGS__);     \
-      x(__VA_ARGS__);                                           \
-      kv_parser_testcase_end();                               \
-  } while(0)
+#include <criterion/criterion.h>
 
+GlobalConfig *cfg;
 LogParser *kv_parser;
 
 static LogMessage *
@@ -77,12 +55,31 @@ parse_kv_into_log_message(const gchar *kv)
   LogMessage *msg;
 
   msg = parse_kv_into_log_message_no_check(kv);
-  assert_not_null(msg, "expected kv-parser success and it returned failure, kv=%s", kv);
+  cr_assert_not_null(msg, "expected kv-parser success and it returned failure, kv=%s", kv);
   return msg;
 }
 
-static void
-test_kv_parser_basics(void)
+void
+setup(void)
+{
+  app_startup();
+  cfg = cfg_new_snippet();
+  kv_parser = kv_parser_new(cfg);
+  log_pipe_init((LogPipe *)kv_parser);
+}
+
+void
+teardown(void)
+{
+  log_pipe_deinit((LogPipe *)kv_parser);
+  log_pipe_unref(&kv_parser->super);
+  scratch_buffers_explicit_gc();
+  cfg_free(cfg);
+  app_shutdown();
+}
+
+
+Test(kv_parser, test_basics)
 {
   LogMessage *msg;
 
@@ -96,22 +93,20 @@ test_kv_parser_basics(void)
   log_msg_unref(msg);
 }
 
-static void
-test_kv_parser_uses_template_to_parse_input(void)
+Test(kv_parser, test_using_template_to_parse_input)
 {
   LogMessage *msg;
   LogTemplate *template;
 
   template = log_template_new(NULL, NULL);
-  log_template_compile(template, "foo=bar", NULL);
+  log_template_compile_literal_string(template, "foo=bar");
   log_parser_set_template(kv_parser, template);
   msg = parse_kv_into_log_message("foo=this-value-doesnot-matter-as-template-overrides");
   assert_log_message_value(msg, log_msg_get_value_handle("foo"), "bar");
   log_msg_unref(msg);
 }
 
-static void
-test_kv_parser_audit(void)
+Test(kv_parser, test_audit)
 {
   LogMessage *msg;
 
@@ -139,20 +134,30 @@ test_kv_parser_audit(void)
   log_msg_unref(msg);
 }
 
-static void
-test_kv_parser(void)
+Test(kv_parser, test_extract_stray_words)
 {
-  KV_PARSER_TESTCASE(test_kv_parser_basics);
-  KV_PARSER_TESTCASE(test_kv_parser_audit);
-  KV_PARSER_TESTCASE(test_kv_parser_uses_template_to_parse_input);
+  LogMessage *msg;
+
+  kv_parser_set_stray_words_value_name(kv_parser, "stray");
+  kv_parser_set_prefix(kv_parser, ".junos.");
+  kv_parser_set_pair_separator(kv_parser, ";");
+  log_pipe_deinit((LogPipe *)kv_parser);
+  log_pipe_init((LogPipe *)kv_parser);
+  msg = parse_kv_into_log_message("VSYS=public; Slot=5/1; protocol=17; source-ip=10.116.214.221; source-port=50989; "
+                                  "destination-ip=172.16.236.16; destination-port=162;time=2016/02/18 16:00:07; "
+                                  "interzone-emtn_s1_vpn-enodeb_om inbound; policy=370;");
+  assert_log_message_value_by_name(msg, ".junos.VSYS", "public");
+  assert_log_message_value_by_name(msg, ".junos.Slot", "5/1");
+  assert_log_message_value_by_name(msg, ".junos.protocol", "17");
+  assert_log_message_value_by_name(msg, ".junos.source-ip", "10.116.214.221");
+  assert_log_message_value_by_name(msg, ".junos.source-port", "50989");
+  assert_log_message_value_by_name(msg, ".junos.destination-ip", "172.16.236.16");
+  assert_log_message_value_by_name(msg, ".junos.destination-port", "162");
+  assert_log_message_value_by_name(msg, ".junos.time", "2016/02/18 16:00:07");
+  assert_log_message_value_by_name(msg, ".junos.policy", "370");
+  assert_log_message_value_by_name(msg, "stray", "\"interzone-emtn_s1_vpn-enodeb_om inbound;\"");
+  log_msg_unref(msg);
+
 }
 
-int
-main(int argc G_GNUC_UNUSED, char *argv[] G_GNUC_UNUSED)
-{
-  app_startup();
-
-  test_kv_parser();
-  app_shutdown();
-  return 0;
-}
+TestSuite(kv_parser, .init = setup, .fini = teardown);
