@@ -121,6 +121,7 @@ extern int mqtt_destination_debug;
     KW_TYPE = 10083,               /* KW_TYPE  */
     KW_STATS_MAX_DYNAMIC = 10084,  /* KW_STATS_MAX_DYNAMIC  */
     KW_MIN_IW_SIZE_PER_READER = 10085, /* KW_MIN_IW_SIZE_PER_READER  */
+    KW_WORKERS = 10086,            /* KW_WORKERS  */
     KW_BATCH_LINES = 10087,        /* KW_BATCH_LINES  */
     KW_BATCH_TIMEOUT = 10088,      /* KW_BATCH_TIMEOUT  */
     KW_TRIM_LARGE_MESSAGES = 10089, /* KW_TRIM_LARGE_MESSAGES  */
@@ -229,7 +230,19 @@ extern int mqtt_destination_debug;
     KW_KEEPALIVE = 10518,          /* KW_KEEPALIVE  */
     KW_ADDRESS = 10519,            /* KW_ADDRESS  */
     KW_QOS = 10520,                /* KW_QOS  */
-    KW_MESSAGE_TEMPLATE = 10521    /* KW_MESSAGE_TEMPLATE  */
+    KW_MESSAGE_TEMPLATE = 10521,   /* KW_MESSAGE_TEMPLATE  */
+    KW_USERNAME = 10522,           /* KW_USERNAME  */
+    KW_PASSWORD = 10523,           /* KW_PASSWORD  */
+    KW_HTTP_PROXY = 10524,         /* KW_HTTP_PROXY  */
+    KW_TLS = 10525,                /* KW_TLS  */
+    KW_CA_DIR = 10526,             /* KW_CA_DIR  */
+    KW_CA_FILE = 10527,            /* KW_CA_FILE  */
+    KW_CERT_FILE = 10528,          /* KW_CERT_FILE  */
+    KW_KEY_FILE = 10529,           /* KW_KEY_FILE  */
+    KW_CIPHER_SUITE = 10530,       /* KW_CIPHER_SUITE  */
+    KW_USE_SYSTEM_CERT_STORE = 10531, /* KW_USE_SYSTEM_CERT_STORE  */
+    KW_SSL_VERSION = 10532,        /* KW_SSL_VERSION  */
+    KW_PEER_VERIFY = 10533         /* KW_PEER_VERIFY  */
   };
   typedef enum mqtt_destination_tokentype mqtt_destination_token_kind_t;
 #endif
@@ -289,6 +302,7 @@ extern int mqtt_destination_debug;
 #define KW_TYPE 10083
 #define KW_STATS_MAX_DYNAMIC 10084
 #define KW_MIN_IW_SIZE_PER_READER 10085
+#define KW_WORKERS 10086
 #define KW_BATCH_LINES 10087
 #define KW_BATCH_TIMEOUT 10088
 #define KW_TRIM_LARGE_MESSAGES 10089
@@ -398,6 +412,18 @@ extern int mqtt_destination_debug;
 #define KW_ADDRESS 10519
 #define KW_QOS 10520
 #define KW_MESSAGE_TEMPLATE 10521
+#define KW_USERNAME 10522
+#define KW_PASSWORD 10523
+#define KW_HTTP_PROXY 10524
+#define KW_TLS 10525
+#define KW_CA_DIR 10526
+#define KW_CA_FILE 10527
+#define KW_CERT_FILE 10528
+#define KW_KEY_FILE 10529
+#define KW_CIPHER_SUITE 10530
+#define KW_USE_SYSTEM_CERT_STORE 10531
+#define KW_SSL_VERSION 10532
+#define KW_PEER_VERIFY 10533
 
 /* Value type.  */
 #if ! defined MQTT_DESTINATION_STYPE && ! defined MQTT_DESTINATION_STYPE_IS_DECLARED
