@@ -23,14 +23,54 @@
  *
  */
 #include "python-value-pairs.h"
+#include "python-helpers.h"
+#include "messages.h"
 
 /** Value pairs **/
 
-/* TODO escape '\0' when passing down the value */
+static void
+add_long_to_dict(PyObject *dict, const gchar *name, long num)
+{
+
+  PyObject *pyobject_to_add = PyLong_FromLong(num);
+  if (!pyobject_to_add)
+    {
+      gchar buf[256];
+      _py_format_exception_text(buf, sizeof(buf));
+
+      msg_error("Error while constructing python object",
+                evt_tag_str("exception", buf));
+      _py_finish_exception_handling();
+      return;
+    }
+
+  PyDict_SetItemString(dict, name, pyobject_to_add);
+  Py_DECREF(pyobject_to_add);
+}
+
+static void
+add_string_to_dict(PyObject *dict, const gchar *name, const char *value, gsize value_len)
+{
+  PyObject *pyobject_to_add = PyBytes_FromStringAndSize(value, value_len);
+  if (!pyobject_to_add)
+    {
+      gchar buf[256];
+      _py_format_exception_text(buf, sizeof(buf));
+
+      msg_error("Error while constructing python object",
+                evt_tag_str("exception", buf));
+      _py_finish_exception_handling();
+      return;
+    }
+
+  PyDict_SetItemString(dict, name, pyobject_to_add);
+  Py_DECREF(pyobject_to_add);
+}
+
 static gboolean
 python_worker_vp_add_one(const gchar *name,
-                       TypeHint type, const gchar *value, gsize value_len,
-                       gpointer user_data)
+                         TypeHint type, const gchar *value, gsize value_len,
+                         gpointer user_data)
 {
   const LogTemplateOptions *template_options = (const LogTemplateOptions *)((gpointer *)user_data)[0];
   PyObject *dict = (PyObject *)((gpointer *)user_data)[1];
@@ -41,48 +81,53 @@ python_worker_vp_add_one(const gchar *name,
     {
     case TYPE_HINT_INT32:
     case TYPE_HINT_INT64:
-      {
-        gint64 i;
+    {
+      gint64 i;
 
-        if (type_cast_to_int64(value, &i, NULL))
-          PyDict_SetItemString(dict, name, PyLong_FromLong(i));
-        else
-          {
-            need_drop = type_cast_drop_helper(template_options->on_error,
-                                              value, "int");
+      if (type_cast_to_int64(value, &i, NULL))
+        {
+          add_long_to_dict(dict, name, i);
+        }
+      else
+        {
+          need_drop = type_cast_drop_helper(template_options->on_error,
+                                            value, "int");
 
-            if (fallback)
-              PyDict_SetItemString(dict, name, PyUnicode_FromString(value));
-          }
-        break;
-      }
+          if (fallback)
+            {
+              add_string_to_dict(dict, name, value, value_len);
+            }
+        }
+      break;
+    }
     case TYPE_HINT_STRING:
-      PyDict_SetItemString(dict, name, PyUnicode_FromString(value));
+      add_string_to_dict(dict, name, value, value_len);
       break;
     default:
       need_drop = type_cast_drop_helper(template_options->on_error,
                                         value, "<unknown>");
       break;
     }
+
   return need_drop;
 }
 
 /** Main code **/
 
 gboolean
-py_value_pairs_apply(ValuePairs *vp, const LogTemplateOptions *template_options, guint32 seq_num, LogMessage *msg, PyObject **dict)
+py_value_pairs_apply(ValuePairs *vp, LogTemplateEvalOptions *options, LogMessage *msg,
+                     PyObject **dict)
 {
   gpointer args[2];
   gboolean vp_ok;
 
   *dict = PyDict_New();
 
-  args[0] = (gpointer) template_options;
+  args[0] = (gpointer) options->opts;
   args[1] = *dict;
 
   vp_ok = value_pairs_foreach(vp, python_worker_vp_add_one,
-                              msg, seq_num, LTZ_LOCAL, template_options,
-                              args);
+                              msg, options, args);
   if (!vp_ok)
     {
       Py_DECREF(*dict);
