@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.3.  */
+/* A Bison parser, made by GNU Bison 3.7.6.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -81,6 +81,8 @@ extern int tags_parser_debug;
     LL_CONTEXT_CLIENT_PROTO = 17,  /* LL_CONTEXT_CLIENT_PROTO  */
     LL_CONTEXT_SERVER_PROTO = 18,  /* LL_CONTEXT_SERVER_PROTO  */
     LL_CONTEXT_OPTIONS = 19,       /* LL_CONTEXT_OPTIONS  */
+    LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
+    LL_CONTEXT_MAX = 21,           /* LL_CONTEXT_MAX  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
     KW_PARSER = 10002,             /* KW_PARSER  */
@@ -111,6 +113,7 @@ extern int tags_parser_debug;
     KW_TYPE = 10083,               /* KW_TYPE  */
     KW_STATS_MAX_DYNAMIC = 10084,  /* KW_STATS_MAX_DYNAMIC  */
     KW_MIN_IW_SIZE_PER_READER = 10085, /* KW_MIN_IW_SIZE_PER_READER  */
+    KW_WORKERS = 10086,            /* KW_WORKERS  */
     KW_BATCH_LINES = 10087,        /* KW_BATCH_LINES  */
     KW_BATCH_TIMEOUT = 10088,      /* KW_BATCH_TIMEOUT  */
     KW_TRIM_LARGE_MESSAGES = 10089, /* KW_TRIM_LARGE_MESSAGES  */
@@ -218,6 +221,7 @@ extern int tags_parser_debug;
   typedef enum tags_parser_tokentype tags_parser_token_kind_t;
 #endif
 /* Token kinds.  */
+#define TAGS_PARSER_EMPTY -2
 #define TAGS_PARSER_EOF 0
 #define TAGS_PARSER_error 256
 #define TAGS_PARSER_UNDEF 10514
@@ -240,6 +244,8 @@ extern int tags_parser_debug;
 #define LL_CONTEXT_CLIENT_PROTO 17
 #define LL_CONTEXT_SERVER_PROTO 18
 #define LL_CONTEXT_OPTIONS 19
+#define LL_CONTEXT_CONFIG 20
+#define LL_CONTEXT_MAX 21
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
 #define KW_PARSER 10002
@@ -270,6 +276,7 @@ extern int tags_parser_debug;
 #define KW_TYPE 10083
 #define KW_STATS_MAX_DYNAMIC 10084
 #define KW_MIN_IW_SIZE_PER_READER 10085
+#define KW_WORKERS 10086
 #define KW_BATCH_LINES 10087
 #define KW_BATCH_TIMEOUT 10088
 #define KW_TRIM_LARGE_MESSAGES 10089
